@@ -1,11 +1,13 @@
+use crate::client::connections::UserCon;
+use crate::client::user_con;
+use crate::general::ConnectionReader;
 use crate::streams::mpsc;
-use crate::{client::queues, general::ConnectionReader};
+use crate::Details;
 use crate::{
     client::Handler,
     message::{Message, MessageHeader, MessageType},
 };
 use crate::{connections::Connections, metrics::Metrics};
-use crate::{objectpool, Details};
 
 use std::sync::Arc;
 
@@ -26,8 +28,6 @@ struct SingleOptions<'a, R> {
     /// The Buffer that should be used for Deserializing the Header
     /// into it
     head_buf: &'a mut [u8; 13],
-    /// The Obeject Pool that should be used
-    obj_pool: &'a objectpool::Pool<Vec<u8>>,
 }
 
 /// Receives a single Message from the external Server and processes
@@ -83,13 +83,16 @@ where
             };
 
             // Setup the send channel for requests for this user
-            let (tx, handle_rx) = mpsc::stream();
+            let (tx, stream_rx) = mpsc::stream();
             // Add the Connection to the current map of user-connection
             opts.client_cons.set(id, tx);
-            let handle_tx =
-                queues::Sender::new(id, opts.send_queue.clone(), opts.client_cons.clone());
 
-            tokio::task::spawn(H::new_con(handler, id, details, handle_rx, handle_tx));
+            let handle_rx = user_con::OwnedReceiver::new(stream_rx);
+            let handle_tx =
+                user_con::OwnedSender::new(id, opts.send_queue.clone(), opts.client_cons.clone());
+
+            let handle_con = UserCon::new(handle_rx, handle_tx);
+            tokio::task::spawn(H::new_con(handler, id, details, handle_con));
 
             debug!("Established new Connection: {}", id);
 
@@ -106,11 +109,10 @@ where
     metrics.recv_bytes(header.get_length());
 
     let data_length = header.get_length() as usize;
-    let mut buf = opts.obj_pool.get();
-    buf.resize(data_length, 0);
+    let mut buf = vec![0; data_length];
 
     let msg = match opts.server_con.read_full(&mut buf).await {
-        Ok(_) => Message::new_guarded(header, buf),
+        Ok(_) => Message::new(header, buf),
         Err(e) => {
             error!("Receiving Data: {}", e);
             opts.client_cons.remove(id);
@@ -159,7 +161,6 @@ pub async fn receiver<R, H, M>(
     M: Metrics + Send + Sync,
 {
     let mut head_buf = [0; 13];
-    let obj_pool: objectpool::Pool<Vec<u8>> = objectpool::Pool::new(50);
 
     loop {
         let opts = SingleOptions {
@@ -167,7 +168,6 @@ pub async fn receiver<R, H, M>(
             send_queue: &send_queue,
             client_cons: &client_cons,
             head_buf: &mut head_buf,
-            obj_pool: &obj_pool,
         };
         if let Err(e) = receive_single(opts, handler.clone(), metrics.as_ref()).await {
             error!("Receiving: {:?}", e);
@@ -178,10 +178,12 @@ pub async fn receiver<R, H, M>(
 
 #[cfg(test)]
 mod tests {
+    use std::net::{IpAddr, Ipv4Addr};
+
     use super::*;
+    use crate::client::mocks as client_mocks;
     use crate::general::mocks;
     use crate::metrics::Empty;
-    use crate::{client::mocks as client_mocks, DetailsIP};
 
     #[tokio::test]
     async fn valid_sends_data_to_correct_handler() {
@@ -201,7 +203,6 @@ mod tests {
         client_cons.set(id, client_tx);
 
         let mut head_buf = [0; 13];
-        let obj_pool = objectpool::Pool::new(2);
 
         let result = receive_single(
             SingleOptions {
@@ -209,7 +210,6 @@ mod tests {
                 send_queue: &queue_tx,
                 client_cons: &client_cons,
                 head_buf: &mut head_buf,
-                obj_pool: &obj_pool,
             },
             Arc::new(client_mocks::EmptyHandler::new()),
             &Empty::new(),
@@ -231,7 +231,7 @@ mod tests {
     async fn valid_establish_connection() {
         let id = 13;
 
-        let details = Details::new(DetailsIP::IPV4([0, 0, 0, 0])).serialize();
+        let details = Details::new(IpAddr::V4(Ipv4Addr::from([0, 0, 0, 0]))).serialize();
 
         let mut tmp_reader = mocks::MockReader::new();
         tmp_reader.add_message(Message::new(
@@ -244,7 +244,6 @@ mod tests {
         let client_cons = std::sync::Arc::new(Connections::<mpsc::StreamWriter<Message>>::new());
 
         let mut head_buf = [0; 13];
-        let obj_pool = objectpool::Pool::new(2);
 
         let result = receive_single(
             SingleOptions {
@@ -252,7 +251,6 @@ mod tests {
                 send_queue: &queue_tx,
                 client_cons: &client_cons,
                 head_buf: &mut head_buf,
-                obj_pool: &obj_pool,
             },
             Arc::new(client_mocks::EmptyHandler::new()),
             &Empty::new(),
