@@ -2,6 +2,7 @@ use crate::{
     general::{ConnectionReader, ConnectionWriter},
     handshake::HandshakeError,
     message::{Message, MessageHeader, MessageType},
+    PROTOCOL_VERSION,
 };
 
 use rand::rngs::OsRng;
@@ -126,5 +127,13 @@ where
         return Err(HandshakeError::InvalidPort);
     }
 
+    // Check the Protocol Version for Compatibility
+    if config.protocol_version() > PROTOCOL_VERSION + 1 {
+        return Err(HandshakeError::MismatchedProtocol {
+            current: PROTOCOL_VERSION,
+            other: config.protocol_version(),
+        });
+    }
+
     Ok(config)
 }
